Rails.application.routes.draw do
  devise_for :users

  namespace :auth do
    mount_devise_token_auth_for 'User', skip: [:omniauth_callbacks]
  end

  namespace :management do
    root 'welcome#index'

    resources :statistics do
      collection do
        get :users
        get :collections
        get :accesses
        get :downloads
      end
    end

    resources :users
    resources :carousels
  end

  root 'welcome#index'

  resources :learning_objects do
    member do
      post :like
    end
  end

  resources :institutions
  resources :collections
  resources :subjects, only: [:index, :show]

  get 'users/:id', to: 'users#show', as: 'users_show'

  get '/faq' => 'welcome#faq'
  get '/contact' => 'welcome#contact', as: 'contact'
  get '/complaint' => 'welcome#complaint', as: 'complaint'
  get '/search' => 'search#index', as: 'search'
end
